@@ -14,7 +14,7 @@
 
 import uuid
 
-from oslo.config import cfg
+from oslo_config import cfg
 import six
 
 CONF = cfg.CONF
